@@ -1,8 +1,10 @@
 use serde::{Deserialize, Serialize};
 
+/// Games
 #[derive(Serialize, Deserialize, Clone, Default, Debug, PartialEq)]
 pub struct Games {
-    /// A Boolean value that indicates whether users of the app may see and compare achievements on a leaderboard, invite friends, and start multiplayer games.
+    /// A Boolean value that indicates whether users of the app may see and compare
+    /// achievements on a leaderboard, invite friends, and start multiplayer games.
     ///
     /// To add this entitlement to your app, enable the Game Center capability in Xcode.
     ///
@@ -12,7 +14,7 @@ pub struct Games {
     /// ## Framework
     /// * GameKit
     #[serde(
-        rename(serialize = "com.apple.developer.game-center"),
+        rename = "com.apple.developer.game-center",
         skip_serializing_if = "Option::is_none"
     )]
     pub game_center: Option<bool>,
